@@ -1680,3 +1680,45 @@ def test_oebuild_handle_cancel(mocker, config, response, monkeypatch):
     with pytest.raises(tuxsuite.exceptions.URLNotFound):
         tuxsuite.cli.main()
     assert post_req.call_count == 1
+
+
+class TestRemoteVersion:
+    def test_failure(self, monkeypatch, mocker, tuxsuite_config, response, capsys):
+        """Test running cli() with --remote-version option failure case"""
+        response.status_code = 404
+        get_req = mocker.patch("requests.get", return_value=response)
+        monkeypatch.setattr(sys, "argv", ["tuxsuite", "--remote-version"])
+        with pytest.raises(SystemExit) as exc:
+            tuxsuite.cli.main()
+        assert exc.value.code == 1
+        assert exc.type == SystemExit
+        assert get_req.call_count == 1
+        output, error = capsys.readouterr()
+        assert "Error: Unable to fetch remote version" in error
+
+    def test_happy_flow(self, mocker, monkeypatch, tuxsuite_config, response, capsys):
+        """Test running cli() with --remote-version success case"""
+        response.status_code = 200
+        response._content = str.encode(
+            json.dumps(
+                {
+                    "versions": {
+                        "tuxbake": "0.3.1",
+                        "tuxmake": "1.10.0",
+                        "tuxrun": "0.36.0",
+                    }
+                }
+            )
+        )
+        get_req = mocker.patch("requests.get", return_value=response)
+        monkeypatch.setattr(sys, "argv", ["tuxsuite", "--remote-version"])
+        with pytest.raises(SystemExit) as exc:
+            tuxsuite.cli.main()
+        assert exc.value.code == 0
+        assert exc.type == SystemExit
+        assert get_req.call_count == 1
+
+        output, error = capsys.readouterr()
+        assert "tuxbake: 0.3.1" in output
+        assert "tuxmake: 1.10.0" in output
+        assert "tuxrun: 0.36.0" in output
