@@ -212,68 +212,6 @@ class Config:
 InvalidConfiguration = tuxsuite.exceptions.InvalidConfiguration
 
 
-class BuildSetConfig:
-    def __init__(self, set_name, filename=None):
-        self.name = set_name
-        self.description = set_name
-        self.set_name = set_name
-        if filename:
-            self.filename = filename
-        else:
-            self.filename = os.path.expanduser(get_config_file("builds.yaml"))
-        self.plan = []
-        self.__load_config__()
-
-    def __load_config__(self):
-        filename = self.filename
-        set_name = self.set_name
-        try:
-            if re.match(r"^https?://", str(filename)):
-                contents = self.__fetch_remote_config__(filename)
-            else:
-                contents = open(filename).read()
-            config = yaml.safe_load(contents)
-        except (FileNotFoundError, yaml.loader.ParserError) as e:
-            raise InvalidConfiguration(str(e))
-        if not config:
-            raise InvalidConfiguration(
-                f"Build set configuration in {filename} is empty"
-            )
-        if "sets" not in config:
-            raise InvalidConfiguration('Missing "sets" key')
-
-        for set_config in config["sets"]:
-            if set_config["name"] == set_name:
-                self.name = set_config["name"]
-                self.description = set_config["name"]
-
-                if "builds" in set_config:
-                    builds = []
-                    builds = set_config["builds"]
-                    if builds:
-                        for build in builds:
-                            self.plan.append({"build": build, "tests": []})
-
-                    if not self.plan:
-                        raise InvalidConfiguration(
-                            f'Build list is empty for set "{set_name}"'
-                        )
-                    return
-                else:
-                    raise InvalidConfiguration(
-                        f'No "builds" field defined for set "{set_name}"'
-                    )
-        raise InvalidConfiguration(f'No build set named "{set_name}" in {filename}')
-
-    def __fetch_remote_config__(self, url):
-        result = requests.get(url)
-        if result.status_code != 200:
-            raise InvalidConfiguration(
-                f"Unable to retrieve {url}: {result.status_code} {result.reason}"
-            )
-        return result.text
-
-
 class PlanConfig:
     def __init__(self, name, description, filename, job_name=None):
         self.name = name
